### 通用参数说明

以下参数放在 url 后

| 字段      | 数据类型 | 说明              |
| --------- | -------- | ----------------- |
| groupCode | String   | 集团编码          |
| projectId | String   | 项目 id, 不可为空 |
| appId     | String   | 应用 id           |

### 基础接口: 查询实时数据

接口说明

```
查询对象绑点信息点的实时数据
```

请求地址

```
POST: /iot/data/current
```

请求参数

```
[
    { "objectId": "Eqxxxxx", "infoCode": "Tdb" },
    { "objectId": "Eqxxxxx", "infoCode": "CO2" },
    { "objectId": "Eqxxxxx", "infoCode": "Hcho" }
]
```

返回内容

```
{
    "result": "success",
    "data": [
        {
            "objectId": "Eqxxxxx",
            "infoCode": "Tdb",
            "infoValue": "8000-123",
            "data": 25.6,
            "time": "20200512172435"
        },
        {
            "objectId": "Eqxxxxx",
            "infoCode": "Tdb",
            "infoValue": "8000-123",
            "data": 25.6,
            "time": "20200512172435"
        },
        {
            "objectId": "Eqxxxxx",
            "infoCode": "Tdb",
            "error": "错误信息:信息点不存在,表号功能号配置错误,断数等"
        }
    ]
}
```

返回内容说明

```
    infoValue: 信息点配置的内容即绑定的表号功能号
    time: 实时数据的采集时间
    data: 实时数据的值

```

### 基础接口: 查询历史数据/分精度数据

接口说明

```
查询对象绑点信息点的历史数据
1. 多点位个数最多支持50个
2. 分钟级数据，单点位支持最大7天数据查询，多点位支持最大1天数据查询；
3. 小时级数据，单点支持最大30天数据查询，多点位支持最大3天数据查询；
4. 日级数据，单点支持最大1年数据查询，多点位支持最大30天数据查询；
```

请求地址

```
POST: /iot/data/history
```

请求参数

```
{
    "startTime": "20200415120000",
    "endTime": "20200501120000",
    "period": "分精度类型，支持 1min、5min、15min、1h、1d",
    "params": [
        {
            "objectId": "对象id",
            "infoCode": "信息点编码",
        },
        {
            "objectId": "对象id",
            "infoCode": "信息点编码",
        }
    ]
}
```

参数说明

```

    startTime:
    period: 必填,间隔
    objectId: 必填,对象id
    infoCode: 必填,信息点ID
```

返回内容

```
{
    "result": "success",
    "data": [
        {
            "objectId": "对象id",
            "infoCode": "信息点编码",
            "data": [
                {
                    "time": "20200415120000"
                    "data": 25.6,
                },
                {
                    "time": "20200415120500"
                    "data": 25.6,
                }
            ]
        },
        {
            "objectId": "对象id",
            "infoCode": "信息点编码",
            "data": [
                {
                    "time": "20200415120000"
                    "data": 25.6,
                },
                {
                    "time": "20200415120500"
                    "data": 25.6,
                }
            ]
        }
    ]
}
```

返回内容说明

```
返回数据的time可能是不连续的

```

### 基础接口: 发送控制指令/设定动态参数

接口说明

```
该接口为异步方式

```

请求地址

```
POST: /iot/funcid/setting
```

请求参数

```
[
    { "objectId": "Eqxxxxx", "infoCode": "FanFreqSet", value: 24 },
    { "objectId": "Eqxxxxx", "infoCode": "InValveSwitchSet", value: "a" },
    { "objectId": "Eqxxxxx", "infoCode": "WaterInOutDetaTempSet", value: 10 }
]
```

请求参数说明

```
value要严格匹配信息点定义的数据类型
```

返回内容

```
{
    "result": "success",
    "data": [
        {
            "objectId": "Eqxxxxx",
            "infoCode": "FanFreqSet",
            "exeCode":"sfge131v4t2vs3423rbsb3"
        },
        {
            "objectId": "Eqxxxxx",
            "infoCode": "InValveSwitchSet",
            "exeCode":"sfge131v4t2vs3423rbsb3"
        },
        {
            "objectId": "Eqxxxxx",
            "infoCode": "InValveSwitchSet",
            "exeCode":"sfge131v4t2vs3423rbsb3"
        }
    ]
}
```

返回内容说明

```
    exeCode: 指令查询码,用于查询指令执行结果
```

### 基础接口: 查询指令执行结果

请求地址

```
POST: /iot/funcid/settingQuery
```

请求参数

```
[ "sfge131v4t2vs3423rbqb3", "e1ge131v4t2vs3423rbsb3", "eaqge131v4t2vs3423rger" ]
```

返回内容

```
{
    "result": "success",
    "data": [
        {
            "exeCode": "sfge131v4t2vs3423rbqb3",
            "exeResult": "timeout",
        },
        {
            "exeCode": "e1ge131v4t2vs3423rbsb3",
            "exeResult": "running",
        },
        {
            "exeCode": "eaqge131v4t2vs3423rger",
            "exeResult": "failed",
        }
    ]
}
```

控制指令执行结果说明(待定)

```

控制指令执行结果为一个字符串，其可能值有以下几种：
- finish:success，执行完成
- timeout，表示控制指令已下发但超过了合理响应时间(默认1minute,系统可配置)至今一直为得到反馈
- running，表示控制指令已下发在合理响应时间内还未得到反馈
- failed，指令未下发出去
- success-offline，指令已下发出去，并得到了反馈，'success-'后面的字符为反馈的信息

```
